@@ -17,5 +17,5 @@ def get_fen_from_image(image_path, end_of_row='/', black_view=False) -> str:
     tiler = Tiler()
     tiles = tiler.get_tiles(image_path=image_path)
     predictions = net.predict(tiles=tiles)
-    fen = decoder.fen_decode(figures=predictions, end_of_row=end_of_row, black_view=black_view)
+    fen = decoder.fen_decode(squares=predictions, end_of_row=end_of_row, black_view=black_view)
     return fen
